@@ -274,7 +274,7 @@ class Desktop(MethodsInterface):
                 cols = [x.strip() for x in line.split()]
                 if len(cols) >= 3:
                     sessionid, uid, username = cols[:3]
-                    if username = urLogin:
+                    if username == urLogin:
                         return sessionid
         finally:
             p.close()
