@@ -32,6 +32,7 @@ from itertools import *
 import glob
 from calculate.lib.cl_template import templateFunction
 from calculate.lib.cl_ini_parser import iniParser
+from calculate.lib.utils.portage import isPkgInstalled
 import hashlib
 
 from calculate.lib.cl_lang import setLocalTranslate
@@ -474,3 +475,23 @@ class VariableClDesktopFastloginPath(ReadonlyVariable):
     Путь до каталога в котором указаны пользователи быстрого входа в сеанс
     """
     value = "/var/lib/calculate/calculate-desktop/fastlogin"
+
+class VariableClDesktopElogindSet(ReadonlyVariable):
+    """
+    В системе используется elogind
+    """
+    def get(self):
+        
+class VariableClDesktopElogindSet(ReadonlyVariable):
+    """
+    Установлен ли x11-base/xorg-server
+    """
+    type = Variable.Types.Boolean
+    elogind = "sys-auth/elogind"
+    consolekit = "sys-auth/consolekit"
+
+    def get(self):
+        if isPkgInstalled(elogind) and \
+            not isPkgInstalled(consolekit):
+            return Variable.On
+        return Variable.Off
